############################################################################################
#!/bin/bash
# Title: security-lockdown.sh
# Description: Wrapper script to start the worker_security-lockdown_el[67].sh script with logging.
# Author(s): Bill Howe
# Last Updated: 12/18/2015
# Most Recent Changes:-Initial
############################################################################################

## Ensure we are root ##
if [[ $(id --user) -ne 0 ]]; then
  echo ">>Error; this script must be run as root. Exiting..."
  exit 1
fi

##======================
## Set Script Variables 
##======================

# Set base path from executed command (relative or full path works)
base_path="$(echo ${0} | sed 's/security-lockdown.sh//')"

# Set log file and script locations
security_log="/root/security-lockdown.log"
security_warnings="/root/security-lockdown_warnings.log"

## Select child script (worker) based on OS ##

# Gather distro and major version
if [ -f /etc/system-release-cpe ]; then
  distro=$(awk -F: '{printf "%s", $3}' /etc/system-release-cpe)
  major_version=$(awk -F: '{printf "%d", $5}' /etc/system-release-cpe)
elif [ -f /etc/redhat-release ]; then
  distro=$(awk '{printf "%s", $1}' /etc/redhat-release)
  major_version=$(awk -F. '{print $1}' /etc/redhat-release | awk '{printf "%d", $3}')
fi

# ${distro,,} converts to lower case for comparison
if [[ ${distro,,} == "centos" || ${distro,,} == "oracle" ]]; then
  case ${major_version} in
  "7") 
    security_worker="worker_security-lockdown_el7.sh"
  ;;
  "6")
    security_worker="worker_security-lockdown_el6.sh"
  ;;
  *)
    echo ">>Error: This Security Lockdown script is for CentOS/Oracle Linux 6/7 only. Exiting..."
    exit 1
  ;;
  esac
else
  echo ">>Error: This Security Lockdown script is for CentOS/Oracle Linux only. Exiting..."
  exit 1
fi

##================
## Setup Logging 
##================
echo -e ">>Logging output and errors to: ${security_log}\n"

# Clear logs and timestamp the beginning
cat /dev/null > ${security_log}
cat /dev/null > ${security_warnings}
echo -e "---- Log Started: $(date) ----\n" >> ${security_log}

##=========================
## Execute External Scripts 
##=========================
# Start script, pass base path argument
${base_path}${security_worker} ${base_path} 2>&1 | tee -a ${security_log}

## Grab Warnings From the Log
grep -i ">Warning" ${security_log} > ${security_warnings}

##==========================
## Close Logs, Show Location 
##==========================
# Ending timestamp
echo -e "\n---- Log Completed: $(date) ----" >> ${security_log}

# Reminder of where the log file is at
echo -e "\n>>Logged output and errors were sent to: ${security_log}"
echo -e ">>Warnings have been sent to: ${security_warnings}\n"


